@@ -10,13 +10,15 @@
 #include <QString>
 #include <QVariant>
 
+#include <memory>
+
 #include "kfilemetadata_export.h"
 #include "embeddedimagedata.h"
 #include "properties.h"
 #include "types.h"
 
 namespace KFileMetaData {
-
+class ExtractionResultPrivate;
 /**
  * \class ExtractionResult extractionresult.h <KFileMetaData/ExtractionResult>
  *
@@ -42,7 +44,7 @@ public:
         ExtractImageData = 4, ///< @since 5.76
 #if KFILEMETADATA_ENABLE_DEPRECATED_SINCE(5, 76)
 	/// @deprecated since 5.76, specify explicitly
-        ExtractEverything = (ExtractMetaData | ExtractPlainText)
+        ExtractEverything KFILEMETADATA_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 76, "Specify flags explicitly") = (ExtractMetaData | ExtractPlainText)
 #endif
     };
     /**
@@ -128,8 +130,7 @@ public:
     QMap<EmbeddedImageData::ImageType, QByteArray> imageData() const;
 
 private:
-    class Private;
-    Private* d;
+    const std::unique_ptr<ExtractionResultPrivate> d;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(ExtractionResult::Flags)
