@@ -10,6 +10,7 @@
 
 
 #include "ffmpegextractor.h"
+#include "kfilemetadata_debug.h"
 
 #include "config-kfilemetadata.h"
 
@@ -27,8 +28,6 @@ extern "C" {
 #include <libavcodec/avcodec.h>
 }
 
-#include <QDebug>
-
 using namespace KFileMetaData;
 
 FFmpegExtractor::FFmpegExtractor(QObject* parent)
@@ -59,19 +58,21 @@ void FFmpegExtractor::extract(ExtractionResult* result)
 {
     AVFormatContext* fmt_ctx = nullptr;
 
+#if LIBAVFORMAT_VERSION_MAJOR < 58
     av_register_all();
+#endif
 
     QByteArray arr = result->inputUrl().toUtf8();
 
     fmt_ctx = avformat_alloc_context();
     if (int ret = avformat_open_input(&fmt_ctx, arr.data(), nullptr, nullptr)) {
-        qWarning() << "avformat_open_input error: " << ret;
+        qCWarning(KFILEMETADATA_LOG) << "avformat_open_input error: " << ret;
         return;
     }
 
     int ret = avformat_find_stream_info(fmt_ctx, nullptr);
     if (ret < 0) {
-        qWarning() << "avform_find_stream_info error: " << ret;
+        qCWarning(KFILEMETADATA_LOG) << "avform_find_stream_info error: " << ret;
         return;
     }
 
@@ -84,13 +85,11 @@ void FFmpegExtractor::extract(ExtractionResult* result)
         result->add(Property::Duration, totalSecs);
         result->add(Property::BitRate, bitrate);
 
-        for (uint i = 0; i < fmt_ctx->nb_streams; i++) {
-            AVStream* stream = fmt_ctx->streams[i];
-#if defined HAVE_AVSTREAM_CODECPAR && HAVE_AVSTREAM_CODECPAR
+        const int index_stream = av_find_default_stream_index(fmt_ctx);
+        if (index_stream >= 0) {
+            AVStream* stream = fmt_ctx->streams[index_stream];
+
             const AVCodecParameters* codec = stream->codecpar;
-#else
-            const AVCodecContext* codec = stream->codec;
-#endif
 
             if (codec->codec_type == AVMEDIA_TYPE_VIDEO) {
                 result->add(Property::Width, codec->width);
@@ -103,21 +102,31 @@ void FFmpegExtractor::extract(ExtractionResult* result)
                           codec->height * avSampleAspectRatio.den,
                           1024*1024);
                 double displayAspectRatio = avDisplayAspectRatio.num;
-                if (avDisplayAspectRatio.den)
+                if (avDisplayAspectRatio.den) {
                     displayAspectRatio /= avDisplayAspectRatio.den;
-                if (displayAspectRatio)
+                }
+                if (displayAspectRatio) {
                     result->add(Property::AspectRatio, displayAspectRatio);
+                }
 
                 AVRational avFrameRate = av_guess_frame_rate(fmt_ctx, stream, nullptr);
                 double frameRate = avFrameRate.num;
-                if (avFrameRate.den)
+                if (avFrameRate.den) {
                     frameRate /= avFrameRate.den;
-                if (frameRate)
+                }
+                if (frameRate) {
                     result->add(Property::FrameRate, frameRate);
+                }
             }
         }
 
         AVDictionary* dict = fmt_ctx->metadata;
+        // In Ogg, the internal comment metadata headers are attached to a single content stream.
+        // By convention, it's the first logical bitstream occuring.
+        if (!dict && fmt_ctx->nb_streams > 0) {
+            dict = fmt_ctx->streams[0]->metadata;
+        }
+
         AVDictionaryEntry* entry;
 
         entry = av_dict_get(dict, "title", nullptr, 0);
@@ -157,8 +166,9 @@ void FFmpegExtractor::extract(ExtractionResult* result)
 
             bool ok = false;
             int track = value.toInt(&ok);
-            if (ok && track)
+            if (ok && track) {
                 result->add(Property::TrackNumber, track);
+            }
         }
 
         entry = av_dict_get(dict, "year", nullptr, 0);
